pub enum BaseDomain {
Bool,
I64,
F64,
Text,
Bytes,
}Expand description
The five portable base domains.
Variants
Implementations
Sourceimpl BaseDomain
impl BaseDomain
Sourcepub fn spec(self) -> DomainSpec
pub fn spec(self) -> DomainSpec
Returns the complete built-in declaration, suitable for any catalog.
Sourcepub fn to_datum(self, value: StorageValue) -> Result<Datum, DomainError>
pub fn to_datum(self, value: StorageValue) -> Result<Datum, DomainError>
Converts a provider value into its exact kernel datum.
Sourcepub fn from_datum(self, datum: &Datum) -> Result<StorageValue, DomainError>
pub fn from_datum(self, datum: &Datum) -> Result<StorageValue, DomainError>
Converts an exact kernel datum back to the provider representation.